Identifies the most important KEGG pathways or protein domains in the entire database and returns a profile of those with the highest contributions to PCA dimensions.

get_subset_pca(tibble_rbims, cos2_val = NULL, 
analysis = c("KEGG", "Pfam", "INTERPRO", "dbCAN", "MEROPS"))

Arguments

tibble_rbims

A tibble created with functions such as read_interpro(), mapping_ko(), or get_subset_*().

cos2_val

Numeric value between 0 and 1 indicating the cutoff for contribution. Defaults to 0.98. See get_pca.

analysis

Character string specifying the annotation database. Options: "KEGG", "Pfam", "INTERPRO", "dbCAN", "MEROPS".

Details

This function is part of the rbims package for analyzing metabolic potential in metagenome-assembled genomes (MAGs).

Examples

# get_subset_pca(ko_bin_mapp, analysis = "KEGG")